@@ -53,7 +53,7 @@ struct StringTable ChannelsConfLine::modulation_table[] =
 	{ "QAM_128",	QAM_128 },
 	{ "QAM_256",	QAM_256 },
 	{ "QAM_AUTO",	QAM_AUTO },
-	{ "8VSB",		VSB_8 },
+	{ "VSB_8",		VSB_8 },
 	{ "VSB_16",		VSB_16 },
 	{ NULL, 0 }
 };
